package com.itranswarp.learnjava;

import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.condition.*;

public class ConfigTest {

	Config config;

	@BeforeEach
	public void setUp() {
		this.config = new Config();
	}

	@Test
	@EnabledOnOs(OS.WINDOWS)
	void testWindows() {
		assertEquals("C:\\test.ini", config.getConfigFile("test.ini"));
	}

	@Test
	@EnabledOnOs({ OS.LINUX, OS.MAC })
	void testLinuxAndMac() {
		assertEquals("/usr/local/test.cfg", config.getConfigFile("test.cfg"));
	}

	@Test
	@Disabled("bug-101")
	void testBug101() {
		// TODO: this test is disabled for bug fixing
	}

	@Test
	@DisabledOnOs(OS.WINDOWS)
	void testOnNonWindowsOs() {
		// TODO: this test is disabled on windows
	}

	@Test
	@DisabledOnJre(JRE.JAVA_8)
	void testOnJava9OrAbove() {
		// TODO: this test is disabled on java 8
	}

	@Test
	@EnabledIfSystemProperty(named = "os.arch", matches = ".*64.*")
	void testOnlyOn64bitSystem() {
		// TODO: this test is only run on 64 bit system
	}

	@Test
	@EnabledIfEnvironmentVariable(named = "DEBUG", matches = "true")
	void testOnlyOnDebugMode() {
		// TODO: this test is only run on DEBUG=true
	}
}
